@@ -1,21 +1,21 @@
 /*
-64.xlatetof.c - implementation of the elf64_xlateto[fm](3) functions.
-Copyright (C) 1995 - 2002 Michael Riepe <michael@stud.uni-hannover.de>
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*/
+ * 64.xlatetof.c - implementation of the elf64_xlateto[fm](3) functions.
+ * Copyright (C) 1995 - 2004 Michael Riepe
+ * 
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #include <private.h>
 #include <ext_types.h>
@@ -24,25 +24,32 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #if __LIBELF64
 
 #ifndef lint
-static const char rcsid[] = "@(#) $Id: 64.xlatetof.c,v 1.17 2002/12/22 20:08:48 michael Exp $";
+static const char rcsid[] = "@(#) $Id: 64.xlatetof.c,v 1.24 2005/05/21 15:39:20 michael Exp $";
 #endif /* lint */
 
 /*
  * Ugly, ugly
  */
-#define x
-#if defined/**/x
+#ifdef _WIN32
 # define Cat2(a,b)a##b
 # define Cat3(a,b,c)a##b##c
 # define Ex1(m1,m2,a,b)m1##m2(a##b)
 # define Ex2(m1,m2,a,b,c)m1##m2(a,b##c)
-#else
-# define Cat2(a,b)a/**/b
-# define Cat3(a,b,c)a/**/b/**/c
-# define Ex1(m1,m2,a,b)m1/**/m2(a/**/b)
-# define Ex2(m1,m2,a,b,c)m1/**/m2(a,b/**/c)
-#endif
-#undef x
+#else /* _WIN32 */
+# define x
+# if defined/**/x
+#  define Cat2(a,b)a##b
+#  define Cat3(a,b,c)a##b##c
+#  define Ex1(m1,m2,a,b)m1##m2(a##b)
+#  define Ex2(m1,m2,a,b,c)m1##m2(a,b##c)
+# else
+#  define Cat2(a,b)a/**/b
+#  define Cat3(a,b,c)a/**/b/**/c
+#  define Ex1(m1,m2,a,b)m1/**/m2(a/**/b)
+#  define Ex2(m1,m2,a,b,c)m1/**/m2(a,b/**/c)
+# endif
+# undef x
+#endif /* _WIN32 */
 
 /*
  * auxiliary macros for execution order reversal
@@ -301,8 +308,8 @@ xlate64_11[/*encoding*/] = {
 	{ _elf_verdef_64L11_tom,  _elf_verdef_64L11_tof  },
 	{ _elf_verneed_64L11_tom, _elf_verneed_64L11_tof },
 #else /* __LIBELF_SYMBOL_VERSIONS */
-	{ NULL,             NULL            },
-	{ NULL,             NULL            },
+	{ 0,                0               },
+	{ 0,                0               },
 #endif /* __LIBELF_SYMBOL_VERSIONS */
     },
     {
@@ -325,8 +332,8 @@ xlate64_11[/*encoding*/] = {
 	{ _elf_verdef_64M11_tom,  _elf_verdef_64M11_tof  },
 	{ _elf_verneed_64M11_tom, _elf_verneed_64M11_tof },
 #else /* __LIBELF_SYMBOL_VERSIONS */
-	{ NULL,             NULL            },
-	{ NULL,             NULL            },
+	{ 0,                0               },
+	{ 0,                0               },
 #endif /* __LIBELF_SYMBOL_VERSIONS */
     },
 };
